@@ -1,8 +1,9 @@
 from ._base import BaseNewsvendor, DataDrivenMixin
 from ..utils.validation import check_cu_co
-from keras.models import Sequential
-from keras.layers import Dense
-import keras.backend as K
+from tensorflow.keras.models import Sequential
+from tensorflow.keras.layers import Dense
+from tensorflow.keras.backend import switch, less, sum
+
 from sklearn.utils.validation import check_is_fitted
 import numpy as np
 
@@ -85,8 +86,8 @@ class DeepLearningNewsvendor(BaseNewsvendor, DataDrivenMixin):
         """Create a newsvendor loss function with the given under- and overage costs"""
 
         def customized_loss(y_true, y_pred):
-            loss = K.switch(K.less(y_pred, y_true), cu * (y_true - y_pred), co * (y_pred - y_true))
-            return K.sum(loss)
+            loss = switch(less(y_pred, y_true), cu * (y_true - y_pred), co * (y_pred - y_true))
+            return sum(loss)
 
         return customized_loss
 
